@@ -1,3 +1,6 @@
+// FIXME(thaJeztah): remove once we are a module; the go:build directive prevents go from downgrading language version to go1.16:
+//go:build go1.19
+
 package formatter
 
 import "strings"
@@ -16,12 +19,13 @@ const (
 	StatusHeader       = "STATUS"
 	PortsHeader        = "PORTS"
 	ImageHeader        = "IMAGE"
+	ErrorHeader        = "ERROR"
 	ContainerIDHeader  = "CONTAINER ID"
 )
 
 // SubContext defines what Context implementation should provide
 type SubContext interface {
-	FullHeader() interface{}
+	FullHeader() any
 }
 
 // SubHeaderContext is a map destined to formatter header (table format)
@@ -38,19 +42,10 @@ func (c SubHeaderContext) Label(name string) string {
 
 // HeaderContext provides the subContext interface for managing headers
 type HeaderContext struct {
-	Header interface{}
+	Header any
 }
 
 // FullHeader returns the header as an interface
-func (c *HeaderContext) FullHeader() interface{} {
+func (c *HeaderContext) FullHeader() any {
 	return c.Header
 }
-
-func stripNamePrefix(ss []string) []string {
-	sss := make([]string, len(ss))
-	for i, s := range ss {
-		sss[i] = s[1:]
-	}
-
-	return sss
-}
