@@ -1,6 +1,7 @@
 package manifest
 
 import (
+	"context"
 	"strings"
 
 	"github.com/docker/cli/cli"
@@ -15,14 +16,14 @@ func newRmManifestListCommand(dockerCli command.Cli) *cobra.Command {
 		Short: "Delete one or more manifest lists from local storage",
 		Args:  cli.RequiresMinArgs(1),
 		RunE: func(cmd *cobra.Command, args []string) error {
-			return runRm(dockerCli, args)
+			return runRm(cmd.Context(), dockerCli, args)
 		},
 	}
 
 	return cmd
 }
 
-func runRm(dockerCli command.Cli, targets []string) error {
+func runRm(_ context.Context, dockerCli command.Cli, targets []string) error {
 	var errs []string
 	for _, target := range targets {
 		targetRef, refErr := normalizeReference(target)
