@@ -12,14 +12,16 @@ import (
 )
 
 func newRemoveCommand(dockerCli command.Cli) *cobra.Command {
-
 	cmd := &cobra.Command{
 		Use:     "rm SERVICE [SERVICE...]",
 		Aliases: []string{"remove"},
 		Short:   "Remove one or more services",
 		Args:    cli.RequiresMinArgs(1),
 		RunE: func(cmd *cobra.Command, args []string) error {
-			return runRemove(dockerCli, args)
+			return runRemove(cmd.Context(), dockerCli, args)
+		},
+		ValidArgsFunction: func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
+			return CompletionFn(dockerCli)(cmd, args, toComplete)
 		},
 	}
 	cmd.Flags()
@@ -27,11 +29,9 @@ func newRemoveCommand(dockerCli command.Cli) *cobra.Command {
 	return cmd
 }
 
-func runRemove(dockerCli command.Cli, sids []string) error {
+func runRemove(ctx context.Context, dockerCli command.Cli, sids []string) error {
 	client := dockerCli.Client()
 
-	ctx := context.Background()
-
 	var errs []string
 	for _, sid := range sids {
 		err := client.ServiceRemove(ctx, sid)
