@@ -17,7 +17,7 @@ import (
 	"github.com/docker/docker/api/types/versions"
 	"github.com/docker/docker/client"
 	units "github.com/docker/go-units"
-	"github.com/docker/swarmkit/api/defaults"
+	"github.com/moby/swarmkit/v2/api/defaults"
 	"github.com/pkg/errors"
 	"github.com/spf13/cobra"
 	"github.com/spf13/pflag"
@@ -31,7 +31,10 @@ func newUpdateCommand(dockerCli command.Cli) *cobra.Command {
 		Short: "Update a service",
 		Args:  cli.ExactArgs(1),
 		RunE: func(cmd *cobra.Command, args []string) error {
-			return runUpdate(dockerCli, cmd.Flags(), options, args[0])
+			return runUpdate(cmd.Context(), dockerCli, cmd.Flags(), options, args[0])
+		},
+		ValidArgsFunction: func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
+			return CompletionFn(dockerCli)(cmd, args, toComplete)
 		},
 	}
 
@@ -59,7 +62,7 @@ func newUpdateCommand(dockerCli command.Cli) *cobra.Command {
 	flags.SetAnnotation(flagDNSOptionRemove, "version", []string{"1.25"})
 	flags.Var(newListOptsVar(), flagDNSSearchRemove, "Remove a DNS search domain")
 	flags.SetAnnotation(flagDNSSearchRemove, "version", []string{"1.25"})
-	flags.Var(newListOptsVar(), flagHostRemove, "Remove a custom host-to-IP mapping (host:ip)")
+	flags.Var(newListOptsVar(), flagHostRemove, `Remove a custom host-to-IP mapping ("host:ip")`)
 	flags.SetAnnotation(flagHostRemove, "version", []string{"1.25"})
 	flags.Var(&options.labels, flagLabelAdd, "Add or update a service label")
 	flags.Var(&options.containerLabels, flagContainerLabelAdd, "Add or update a container label")
@@ -93,7 +96,7 @@ func newUpdateCommand(dockerCli command.Cli) *cobra.Command {
 	flags.SetAnnotation(flagDNSOptionAdd, "version", []string{"1.25"})
 	flags.Var(&options.dnsSearch, flagDNSSearchAdd, "Add or update a custom DNS search domain")
 	flags.SetAnnotation(flagDNSSearchAdd, "version", []string{"1.25"})
-	flags.Var(&options.hosts, flagHostAdd, "Add a custom host-to-IP mapping (host:ip)")
+	flags.Var(&options.hosts, flagHostAdd, `Add a custom host-to-IP mapping ("host:ip")`)
 	flags.SetAnnotation(flagHostAdd, "version", []string{"1.25"})
 	flags.BoolVar(&options.init, flagInit, false, "Use an init inside each service container to forward signals and reap processes")
 	flags.SetAnnotation(flagInit, "version", []string{"1.37"})
@@ -123,10 +126,9 @@ func newListOptsVarWithValidator(validator opts.ValidatorFctType) *opts.ListOpts
 	return opts.NewListOptsRef(&[]string{}, validator)
 }
 
-// nolint: gocyclo
-func runUpdate(dockerCli command.Cli, flags *pflag.FlagSet, options *serviceOptions, serviceID string) error {
+//nolint:gocyclo
+func runUpdate(ctx context.Context, dockerCli command.Cli, flags *pflag.FlagSet, options *serviceOptions, serviceID string) error {
 	apiClient := dockerCli.Client()
-	ctx := context.Background()
 
 	service, _, err := apiClient.ServiceInspectWithRaw(ctx, serviceID, types.ServiceInspectOptions{})
 	if err != nil {
@@ -192,14 +194,14 @@ func runUpdate(dockerCli command.Cli, flags *pflag.FlagSet, options *serviceOpti
 		}
 	}
 
-	updatedSecrets, err := getUpdatedSecrets(apiClient, flags, spec.TaskTemplate.ContainerSpec.Secrets)
+	updatedSecrets, err := getUpdatedSecrets(ctx, apiClient, flags, spec.TaskTemplate.ContainerSpec.Secrets)
 	if err != nil {
 		return err
 	}
 
 	spec.TaskTemplate.ContainerSpec.Secrets = updatedSecrets
 
-	updatedConfigs, err := getUpdatedConfigs(apiClient, flags, spec.TaskTemplate.ContainerSpec)
+	updatedConfigs, err := getUpdatedConfigs(ctx, apiClient, flags, spec.TaskTemplate.ContainerSpec)
 	if err != nil {
 		return err
 	}
@@ -216,18 +218,19 @@ func runUpdate(dockerCli command.Cli, flags *pflag.FlagSet, options *serviceOpti
 	if err != nil {
 		return err
 	}
-	if sendAuth {
+	switch {
+	case sendAuth:
 		// Retrieve encoded auth token from the image reference
 		// This would be the old image if it didn't change in this update
 		image := spec.TaskTemplate.ContainerSpec.Image
-		encodedAuth, err := command.RetrieveAuthTokenFromImage(ctx, dockerCli, image)
+		encodedAuth, err := command.RetrieveAuthTokenFromImage(dockerCli.ConfigFile(), image)
 		if err != nil {
 			return err
 		}
 		updateOpts.EncodedRegistryAuth = encodedAuth
-	} else if clientSideRollback {
+	case clientSideRollback:
 		updateOpts.RegistryAuthFrom = types.RegistryAuthFromPreviousSpec
-	} else {
+	default:
 		updateOpts.RegistryAuthFrom = types.RegistryAuthFromSpec
 	}
 
@@ -246,10 +249,10 @@ func runUpdate(dockerCli command.Cli, flags *pflag.FlagSet, options *serviceOpti
 		return nil
 	}
 
-	return waitOnService(ctx, dockerCli, serviceID, options.quiet)
+	return WaitOnService(ctx, dockerCli, serviceID, options.quiet)
 }
 
-// nolint: gocyclo
+//nolint:gocyclo
 func updateService(ctx context.Context, apiClient client.NetworkAPIClient, flags *pflag.FlagSet, spec *swarm.ServiceSpec) error {
 	updateBoolPtr := func(flag string, field **bool) {
 		if flags.Changed(flag) {
@@ -724,8 +727,10 @@ func updateUlimits(flags *pflag.FlagSet, ulimits []*units.Ulimit) []*units.Ulimi
 			newUlimits[ulimit.Name] = ulimit
 		}
 	}
-
-	var limits []*units.Ulimit
+	if len(newUlimits) == 0 {
+		return nil
+	}
+	limits := make([]*units.Ulimit, 0, len(newUlimits))
 	for _, ulimit := range newUlimits {
 		limits = append(limits, ulimit)
 	}
@@ -757,7 +762,7 @@ func updateEnvironment(flags *pflag.FlagSet, field *[]string) {
 	}
 }
 
-func getUpdatedSecrets(apiClient client.SecretAPIClient, flags *pflag.FlagSet, secrets []*swarm.SecretReference) ([]*swarm.SecretReference, error) {
+func getUpdatedSecrets(ctx context.Context, apiClient client.SecretAPIClient, flags *pflag.FlagSet, secrets []*swarm.SecretReference) ([]*swarm.SecretReference, error) {
 	newSecrets := []*swarm.SecretReference{}
 
 	toRemove := buildToRemoveSet(flags, flagSecretRemove)
@@ -770,7 +775,7 @@ func getUpdatedSecrets(apiClient client.SecretAPIClient, flags *pflag.FlagSet, s
 	if flags.Changed(flagSecretAdd) {
 		values := flags.Lookup(flagSecretAdd).Value.(*opts.SecretOpt).Value()
 
-		addSecrets, err := ParseSecrets(apiClient, values)
+		addSecrets, err := ParseSecrets(ctx, apiClient, values)
 		if err != nil {
 			return nil, err
 		}
@@ -780,7 +785,7 @@ func getUpdatedSecrets(apiClient client.SecretAPIClient, flags *pflag.FlagSet, s
 	return newSecrets, nil
 }
 
-func getUpdatedConfigs(apiClient client.ConfigAPIClient, flags *pflag.FlagSet, spec *swarm.ContainerSpec) ([]*swarm.ConfigReference, error) {
+func getUpdatedConfigs(ctx context.Context, apiClient client.ConfigAPIClient, flags *pflag.FlagSet, spec *swarm.ContainerSpec) ([]*swarm.ConfigReference, error) {
 	var (
 		// credSpecConfigName stores the name of the config specified by the
 		// credential-spec flag. if a Runtime target Config with this name is
@@ -796,7 +801,7 @@ func getUpdatedConfigs(apiClient client.ConfigAPIClient, flags *pflag.FlagSet, s
 	if flags.Changed(flagCredentialSpec) {
 		credSpec := flags.Lookup(flagCredentialSpec).Value.(*credentialSpecOpt).Value()
 		credSpecConfigName = credSpec.Config
-	} else {
+	} else { //nolint:gocritic // ignore  elseif: can replace 'else {if cond {}}' with 'else if cond {}'
 		// if the credential spec flag has not changed, then check if there
 		// already is a credentialSpec. if there is one, and it's for a Config,
 		// then it's from the old object, and its value is the config ID. we
@@ -829,7 +834,7 @@ func getUpdatedConfigs(apiClient client.ConfigAPIClient, flags *pflag.FlagSet, s
 	}
 
 	if len(resolveConfigs) > 0 {
-		addConfigs, err := ParseConfigs(apiClient, resolveConfigs)
+		addConfigs, err := ParseConfigs(ctx, apiClient, resolveConfigs)
 		if err != nil {
 			return nil, err
 		}
@@ -876,8 +881,8 @@ func removeConfigs(flags *pflag.FlagSet, spec *swarm.ContainerSpec, credSpecName
 }
 
 func envKey(value string) string {
-	kv := strings.SplitN(value, "=", 2)
-	return kv[0]
+	k, _, _ := strings.Cut(value, "=")
+	return k
 }
 
 func buildToRemoveSet(flags *pflag.FlagSet, flag string) map[string]struct{} {
@@ -996,7 +1001,6 @@ func updateDNSConfig(flags *pflag.FlagSet, config **swarm.DNSConfig) error {
 	for _, nameserver := range nameservers {
 		if _, exists := toRemove[nameserver]; !exists {
 			newConfig.Nameservers = append(newConfig.Nameservers, nameserver)
-
 		}
 	}
 	// Sort so that result is predictable.
@@ -1136,48 +1140,44 @@ type hostMapping struct {
 // Entries can be removed by either a specific `<host-name>:<ip-address>` mapping,
 // or by `<host>` alone:
 //
-// - If both IP-address and host-name is provided, the hostname is removed only
-//   from entries that match the given IP-address.
-// - If only a host-name is provided, the hostname is removed from any entry it
-//   is part of (either as canonical host-name, or as alias).
-// - If, after removing the host-name from an entry, no host-names remain in
-//   the entry, the entry itself is removed.
+//   - If both IP-address and host-name is provided, the hostname is removed only
+//     from entries that match the given IP-address.
+//   - If only a host-name is provided, the hostname is removed from any entry it
+//     is part of (either as canonical host-name, or as alias).
+//   - If, after removing the host-name from an entry, no host-names remain in
+//     the entry, the entry itself is removed.
 //
 // For example, the list of host-entries before processing could look like this:
 //
-//    hosts = &[]string{
-//        "127.0.0.2 host3 host1 host2 host4",
-//        "127.0.0.1 host1 host4",
-//        "127.0.0.3 host1",
-//        "127.0.0.1 host1",
-//    }
+//	hosts = &[]string{
+//		"127.0.0.2 host3 host1 host2 host4",
+//		"127.0.0.1 host1 host4",
+//		"127.0.0.3 host1",
+//		"127.0.0.1 host1",
+//	}
 //
 // Removing `host1` removes every occurrence:
 //
-//    hosts = &[]string{
-//        "127.0.0.2 host3 host2 host4",
-//        "127.0.0.1 host4",
-//    }
+//	hosts = &[]string{
+//		"127.0.0.2 host3 host2 host4",
+//		"127.0.0.1 host4",
+//	}
 //
 // Removing `host1:127.0.0.1` on the other hand, only remove the host if the
 // IP-address matches:
 //
-//    hosts = &[]string{
-//        "127.0.0.2 host3 host1 host2 host4",
-//        "127.0.0.1 host4",
-//        "127.0.0.3 host1",
-//    }
+//	hosts = &[]string{
+//		"127.0.0.2 host3 host1 host2 host4",
+//		"127.0.0.1 host4",
+//		"127.0.0.3 host1",
+//	}
 func updateHosts(flags *pflag.FlagSet, hosts *[]string) error {
 	var toRemove []hostMapping
 	if flags.Changed(flagHostRemove) {
 		extraHostsToRemove := flags.Lookup(flagHostRemove).Value.(*opts.ListOpts).GetAll()
 		for _, entry := range extraHostsToRemove {
-			v := strings.SplitN(entry, ":", 2)
-			if len(v) > 1 {
-				toRemove = append(toRemove, hostMapping{IPAddr: v[1], Host: v[0]})
-			} else {
-				toRemove = append(toRemove, hostMapping{Host: v[0]})
-			}
+			hostName, ipAddr, _ := strings.Cut(entry, ":")
+			toRemove = append(toRemove, hostMapping{IPAddr: ipAddr, Host: hostName})
 		}
 	}
 
@@ -1294,9 +1294,9 @@ func updateNetworks(ctx context.Context, apiClient client.NetworkAPIClient, flag
 	// values to spec.TaskTemplate.Networks.
 	specNetworks := spec.TaskTemplate.Networks
 	if len(specNetworks) == 0 {
-		specNetworks = spec.Networks
+		specNetworks = spec.Networks //nolint:staticcheck // ignore SA1019: field is deprecated.
 	}
-	spec.Networks = nil
+	spec.Networks = nil //nolint:staticcheck // ignore SA1019: field is deprecated.
 
 	toRemove := buildToRemoveSet(flags, flagNetworkRemove)
 	idsToRemove := make(map[string]struct{})
@@ -1309,7 +1309,7 @@ func updateNetworks(ctx context.Context, apiClient client.NetworkAPIClient, flag
 	}
 
 	existingNetworks := make(map[string]struct{})
-	var newNetworks []swarm.NetworkAttachmentConfig
+	var newNetworks []swarm.NetworkAttachmentConfig //nolint:prealloc
 	for _, network := range specNetworks {
 		if _, exists := idsToRemove[network.Target]; exists {
 			continue
@@ -1364,7 +1364,7 @@ func updateCredSpecConfig(flags *pflag.FlagSet, containerSpec *swarm.ContainerSp
 		// otherwise, set the credential spec to be the parsed value
 		credSpec := credSpecOpt.Value.(*credentialSpecOpt).Value()
 
-		// if this is a Config credential spec, we we still need to replace the
+		// if this is a Config credential spec, we still need to replace the
 		// value of credSpec.Config with the config ID instead of Name.
 		if credSpec.Config != "" {
 			for _, config := range containerSpec.Configs {
@@ -1407,34 +1407,33 @@ func updateCredSpecConfig(flags *pflag.FlagSet, containerSpec *swarm.ContainerSp
 //
 // Adding/removing capabilities when updating a service is handled as a tri-state;
 //
-// - if the capability was previously "dropped", then remove it from "CapabilityDrop",
-//   but NOT added to "CapabilityAdd". However, if the capability was not yet in
-//   the service's "CapabilityDrop", then it's simply added to the service's "CapabilityAdd"
-// - likewise, if the capability was previously "added", then it's removed from
-//   "CapabilityAdd", but NOT added to "CapabilityDrop". If the capability was
-//   not yet in the service's "CapabilityAdd", then simply add it to the service's
-//   "CapabilityDrop".
+//   - if the capability was previously "dropped", then remove it from "CapabilityDrop",
+//     but NOT added to "CapabilityAdd". However, if the capability was not yet in
+//     the service's "CapabilityDrop", then it's simply added to the service's "CapabilityAdd"
+//   - likewise, if the capability was previously "added", then it's removed from
+//     "CapabilityAdd", but NOT added to "CapabilityDrop". If the capability was
+//     not yet in the service's "CapabilityAdd", then simply add it to the service's
+//     "CapabilityDrop".
 //
 // In other words, given a service with the following:
 //
 // | CapDrop        | CapAdd        |
-// | -------------- | ------------- |
+// |----------------|---------------|
 // | CAP_SOME_CAP   |               |
 //
 // When updating the service, and applying `--cap-add CAP_SOME_CAP`, the previously
 // dropped capability is removed:
 //
 // | CapDrop        | CapAdd        |
-// | -------------- | ------------- |
+// |----------------|---------------|
 // |                |               |
 //
 // After updating the service a second time, applying `--cap-add CAP_SOME_CAP`,
 // capability is now added:
 //
 // | CapDrop        | CapAdd        |
-// | -------------- | ------------- |
+// |----------------|---------------|
 // |                | CAP_SOME_CAP  |
-//
 func updateCapabilities(flags *pflag.FlagSet, containerSpec *swarm.ContainerSpec) {
 	var (
 		toAdd, toDrop map[string]bool
@@ -1506,10 +1505,13 @@ func updateCapabilities(flags *pflag.FlagSet, containerSpec *swarm.ContainerSpec
 }
 
 func capsList(caps map[string]bool) []string {
+	if len(caps) == 0 {
+		return nil
+	}
 	if caps[opts.AllCapabilities] {
 		return []string{opts.AllCapabilities}
 	}
-	var out []string
+	out := make([]string, 0, len(caps))
 	for c := range caps {
 		out = append(out, c)
 	}
